@@ -84,7 +84,7 @@ class Match:
         if self.replacements:
             s += '\nSuggestion: {}'.format('; '.join(self.replacements))
         s += '\n{}\n{}'.format(
-            self.context, ' ' * self.offset + '^' * self.errorLength
+            self.context, ' ' * self.offsetInContext + '^' * self.errorLength
         )
         return s
 
@@ -113,4 +113,4 @@ class Match:
     def __getattr__(self, name):
         if name not in get_match_ordered_dict():
             raise AttributeError('{!r} object has no attribute {!r}'
-                                 .format(self.__class__.__name__, name))
\ No newline at end of file
+                                 .format(self.__class__.__name__, name))
